@@ -87,23 +87,31 @@ sub _parse_yt_list_html {
     my ( $content, $uploader, $tmp ) = @_;
     my $date_sort = @$tmp;
     my $dom = Mojo::DOM->new( $content );
-    $dom->find( 'li[class="channels-content-item yt-shelf-grid-item"]' )
+    $dom->find( 'li[class*="channels-content-item yt-shelf-grid-item"]' )
         ->each(
             sub {
                 my $entry = {
                     uploader  => $uploader,
                     date_sort => ++$date_sort,
                 };
-                my $el_video_id = $_->at(  'h3[class="yt-lockup-title"] > a[class]' );
-                if ( $el_video_id ) {
-                    $entry->{video_id} = $el_video_id->attr( 'href' );
-                    $entry->{video_id} =~ s/^.+=(?=[^=]{11}\z)//;
+
+                my $el_id_and_title = $_->at( 'h3[class*="yt-lockup-title"] > a[class]' );
+                if ( ! defined $el_id_and_title ) {
+                    die "\$el_id_and_title not defined!";
                 }
-                my $el_title = $_->at(  'h3[class="yt-lockup-title"] > a[class]' );
-                if ( $el_title ) {
-                    $entry->{title} = $el_title->attr( 'title' );
+                $entry->{video_id} = $el_id_and_title->attr( 'href' );
+                if ( ! defined $entry->{video_id} ) {
+                    die "1 \$entry->{video_id} not defined!";
                 }
-                my $el_duration = $_->at(  'span[class="video-time"] > span[title]' );
+                if ( $entry->{video_id} =~ m/=([^=]{11})\z/ ) {
+                    $entry->{video_id} = $1;
+                }
+                if ( ! defined $entry->{video_id} ) {
+                    die "2 \$entry->{video_id} not defined!";
+                }
+                $entry->{title} = $el_id_and_title->attr( 'title' );
+
+                my $el_duration = $_->at(  'span[class*="video-time"] > span[title]' );
                 if ( $el_duration ) {
                     my $duration = $el_duration->text;
                     if ( $duration && $duration =~ /^(?:\d\d?:){0,2}\d\d?\z/ ) {
@@ -116,13 +124,13 @@ sub _parse_yt_list_html {
                         $entry->{duration} = $seconds if $seconds;
                     }
                 }
-                my $el_view_count = $_->find( 'ul[class="yt-lockup-meta-info"] > li' )->[0];
+                my $el_view_count = $_->find( 'ul[class*="yt-lockup-meta-info"] > li' )->[0];
                 if ( $el_view_count ) {
                     $entry->{view_count} = $el_view_count->text;
                     $entry->{view_count} =~ s/^([0-9.,]+).+\z/$1/;
                     $entry->{view_count} =~ s/[,.]//g;
                 }
-                my $el_upload_date_rel = $_->find( 'ul[class="yt-lockup-meta-info"] > li' )->[1];
+                my $el_upload_date_rel = $_->find( 'ul[class*="yt-lockup-meta-info"] > li' )->[1];
                 if ( $el_upload_date_rel ) {
                     $entry->{upload_date_rel} = $el_upload_date_rel->text;
                 }
