@@ -135,7 +135,6 @@ sub _menus {
         group_output => [
             [ 'text_unidecode', "- Unmappable infotext" ],
             [ 'max_info_width', "- Max info width"    ],
-            [ 'kb_sec_len',     "- Digits 'k/s'"      ],
         ],
         group_youtube_dl => [
             [ 'use_netrc',         "- Use '.netrc'" ],
@@ -187,11 +186,6 @@ sub set_options {
     for my $key ( %$sub_menus ) {
         push @keys, map { $_->[0] } @{$sub_menus->{$key}};
     }
-
-    ### ###
-    push @keys, 'history_files_checked' if exists $opt->{history_files_checked};
-    ###
-
     my $group = 'main';
     my $backup_old_idx = 0;
     my $old_idx = 0;
@@ -461,12 +455,6 @@ sub set_options {
                 my $digits = 3;
                 _opt_number_range( $opt, $choice, $prompt, $digits );
             }
-            elsif ( $choice eq "kb_sec_len" ) {
-                my ( $min, $max ) = ( 3, 9 );
-                my $prompt = 'Digits for "k/s" (download speed)';
-                my $digits = 1;
-                _opt_number_range( $opt, $choice, $prompt, $digits );
-            }
             elsif ( $choice eq "use_netrc" ) {
                 my $prompt = 'Enable the option --netrc for youtube-dl';
                 my $list = [ qw( no yes ) ];
